#
# spec file for package gluegen2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define src_name gluegen-v%{version}
%define jcppsrc_name jcpp-v%{version}
%global gluegen_devel_dir %{_datadir}/%{name}
%global inst_srcdir %{buildroot}%{gluegen_devel_dir}
Name:           gluegen2
Version:        2.3.2
Release:        11.5
Summary:        Tool for automatic generation the Java and JNI code
License:        BSD-2-Clause
Group:          Development/Libraries/Java
URL:            https://jogamp.org/gluegen/www/
Source0:        http://jogamp.org/deployment/v%{version}/archive/Sources/%{src_name}.tar.xz
Source1:        http://jogamp.org/deployment/v%{version}/archive/Sources/%{jcppsrc_name}.tar.xz
Patch0:         gluegen2-0001-renamed-library.patch
Patch1:         gluegen2-0003-disable-executable-tmp-tests.patch
Patch2:         gluegen2-0004-add-antlr-jar-to-all-targets.patch
Patch3:         gluegen2-0005-use-system-antlib.patch
Patch4:         gluegen2-0006-disable-static-libgcc.patch
Patch5:         gluegen2-0007-add-ppc64-aarch64.patch
Patch6:         gluegen2-0008-jcpp-remove-javax-api.patch
Patch7:         gluegen2-disable-tests.patch
Patch8:         gluegen2-0001-Remove-version-overrides-for-memcpy.patch
Patch9:         gluegen2-jdk9.patch
Patch10:        gluegen2-jdk10.patch
Patch11:        gluegen2-riscv64.patch
BuildRequires:  ant >= 1.9.8
BuildRequires:  ant-antlr
BuildRequires:  ant-contrib
BuildRequires:  ant-junit
BuildRequires:  cpptasks
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-tools
Requires:       java

%description
GlueGen is a tool which automatically generates the Java and JNI code
necessary to call C libraries. It reads as input ANSI C header files and
separate configuration files which provide control over many aspects of
the glue code generation. GlueGen uses a complete ANSI C parser and
an internal representation (IR) capable of representing all C types
to represent the APIs for which it generates interfaces. It has
the ability to perform significant transformations on the IR before
glue code emission. GlueGen is currently powerful enough to bind even
low-level APIs such as the Java Native Interface (JNI) and
the AWT Native Interface (JAWT) back up to the Java programming language.

%package devel
Summary:        Tool for automatic generation the Java and JNI code
Group:          Development/Libraries/Java
Requires:       %{name} = %{version}
Requires:       ant-antlr
Requires:       ant-contrib
Requires:       ant-junit
Requires:       cpptasks
BuildArch:      noarch

%description devel
This package contains gluegen source code needed to build packages.

%prep
%setup -q -n %{jcppsrc_name} -T -b 1
%setup -q -n %{src_name} -T -b 0
cp -pr ../%{jcppsrc_name}/src ./jcpp/
rm -rf src/java/net/highteq/nativetaglet/

%autopatch -p1

# Fix wrong-script-end-of-line-encoding
rm make/scripts/*.bat

# Fix spurious-executable-perm
chmod -x LICENSE.txt
chmod -x doc/manual/index.html

#chmod -x make/stub_includes/*/*
find make/stub_includes/ -type f -print -exec chmod -x {} \;
find make/stub_includes/ -type d -print -exec chmod +x {} \;

#chmod -x src/native/*/*
find src/native/ -type f -print -exec chmod -x {} \;
find src/native/ -type f -print -exec chmod +x {} \;

find src/java/ -type f -exec chmod -x {} \;
find make/scripts -type f -not -name "*.sh" -print -exec chmod -x {} \;

# Fix non-executable-script
find make/scripts -type f -name "*.sh" -print -exec chmod +x {} \;

# Fix script-without-shebang
find make/scripts -type f -name "*.sh" -print -exec sed -i -e '1i#!/bin/sh' {} \;

# Remove bundled dependencies
find -name "*.jar" -type f -print -exec rm {} \;
find -name "*.apk" -type f -print -exec rm {} \;
rm -fr make/lib

# Remove hardcoded classpath
sed -i '/Class-Path/I d' make/Manifest

# git executable should not be used, use true (to avoid checkout) instead
sed -i 's/executable="git"/executable="true"/' make/build.xml

# 7z executable is not provided, use true (to avoid archive) instead
sed -i 's/executable="7z"/executable="true"/' make/jogamp-archivetasks.xml

# mvn executable should not be used, use true (to avoid install) instead
sed -i 's/executable="mvn"/executable="true"/' make/build.xml

%build
cd make
ant -Djava.version=1.8 -Dant.java.version=1.8 \
    -Djavacdebug=false \
    -Djavacdebuglevel=lines,vars,source \
    -Dantlr.jar=$(find-jar antlr) \
    -Djunit.jar=$(find-jar junit) \
    -Dant.jar=$(find-jar ant) \
    -Dant-junit.jar=$(find-jar ant/ant-junit) \
    -Dc.compiler.debug=true \
    all

%install
# arch independent jars
install -Dm 644 build/gluegen.jar %{buildroot}%{_javadir}/%{name}.jar
install -Dm 644 build/gluegen-rt.jar %{buildroot}%{_javadir}/%{name}-rt.jar
# arch specific jars
install -Dm 644 build/gluegen-rt-natives-*.jar %{buildroot}%{_jnidir}/%{name}-rt-natives.jar
# native libraries
install -Dm 755 build/obj/libgluegen-rt.so %{buildroot}%{_libdir}/lib%{name}-rt.so

# source code
mkdir -p %{inst_srcdir} %{inst_srcdir}/build
cp -rdf -t %{inst_srcdir} make
find %{inst_srcdir} -name '*.orig' -type f -delete -print
cp build/artifact.properties %{inst_srcdir}/build/artifact.properties

# Fix spurious executable perms
chmod -x %{buildroot}%{_datadir}/%{name}/make/*.xml
chmod -x %{buildroot}%{_datadir}/%{name}/make/*.cfg
chmod -x %{buildroot}%{_datadir}/%{name}/make/Manifest*
chmod -x %{buildroot}%{_datadir}/%{name}/make/gluegen.properties

%files
%license LICENSE.txt
%{_javadir}/%{name}-rt.jar
%{_jnidir}/%{name}-rt-natives.jar
%{_libdir}/lib%{name}-rt.so

%files devel
%license LICENSE.txt
%{_javadir}/%{name}.jar
%{gluegen_devel_dir}/

%changelog
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%autopatch instead of deprecated %%patchN.
* Wed Feb 21 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Sep 27 2023 Fridrich Strba <fstrba@suse.com>
- Remove dependency on findbugs
- Modified patches:
  * gluegen2-jdk9.patch
  * gluegen2-riscv64.patch
    + rediff to changed context
  * gluegen2-jar-paths.patch
  - > gluegen2-0005-use-system-antlib.patch
  * gluegen2-add-ppc64-aarch64.patch
  - > gluegen2-0007-add-ppc64-aarch64.patch
  * gluegen2-no-static-libstdc++.patch
  - > gluegen2-0006-disable-static-libgcc.patch
    + rediff and rename
- Added patch:
  * gluegen2-0008-jcpp-remove-javax-api.patch
    + remove code quality annotations not necessary for our build
* Sun Feb  6 2022 Andreas Schwab <schwab@suse.de>
- Added patch:
  * gluegen2-riscv64.patch
    + Add support for riscv64
* Thu May 17 2018 fstrba@suse.com
- Build with source and target 8 to prepare for a possible removal
  of 1.6 compatibility
* Fri Dec 22 2017 fstrba@suse.com
- Added patch:
  * gluegen2-jdk10.patch
  - Fix build with jdk10 by generating headers in javac target
- Require ant >= 1.9.8 that understands "nativeheaderdir" attribute
  and java-devel >= 1.8 that understands javac -h option
* Sat Nov 25 2017 stefan.bruens@rwth-aachen.de
- Fix building of dependent packages (e.g. jogl2) on ARMv7/Aarch64
  * Drop gluegen2-missing-arch-symbol.patch
  * Add gluegen2-0001-Remove-version-overrides-for-memcpy.patch
* Fri Oct  6 2017 fstrba@suse.com
- Added patch:
  * gluegen2-jdk9.patch
    + Fix build with jdk9
- Allow building with jdk9
* Mon Sep 18 2017 fstrba@suse.com
- Build for the while with java < 1.9
* Fri May 19 2017 tchvatal@suse.com
- Remove ant and junit deps to reduce buildgraph
* Wed Mar  9 2016 dvaleev@suse.com
- Don't try to guess glbc version on other architectures
  (gluegen2-missing-arch-symbol.patch)
* Sun Oct 11 2015 badshah400@gmail.com
- Update to version 2.3.2:
  + See http://jogamp.org/deployment/v2.3.2/archive/ChangeLogs/gluegen-ShortLog-v2.3.2.txt
    for a list of changes.
- Upstream switched to using tar.xz for source tarballs; adapt
  %%setup acordingly, drop p7zip BuildRequires.
- Add gluegen2-no-static-libstdc++.patch to prevent the buildtools
  from adding a "-static-libstdc++" option to linker, adding this
  flag causes builds to fail.
* Tue Sep  1 2015 normand@linux.vnet.ibm.com
- put back patch updated for last version 2.3.1:
  gluegen2-add-ppc64-aarch64.patch
* Wed Apr  8 2015 tchvatal@suse.com
- Drop the aach64 patch, not sure if still needed and if so we
  can reintroduce it later:
  * gluegen2-ppc64-aarch64.patch
* Sat Apr  4 2015 badshah400@gmail.com
- Update to version 2.3.1:
  + See gluegen changes from
    https://jogamp.org/wiki/index.php/SW_Tracking_Report_Objectives_for_the_release_2.3.1.
- Add source tarball for jcpp as gluegen now uses jcpp as the
  default compiler; extract and copy jccp sources into gluegen
  build tree during %%prep.
- Add BuildRequires: ant-findbugs.
* Fri Apr  3 2015 badshah400@gmail.com
- Update to version 2.3.0:
  + See gluegen changes from
    https://jogamp.org/wiki/index.php/SW_Tracking_Report_Objectives_for_the_release_2.3.0.
- Add gluegen2-disable-tests.patch to disable junit tests as this
  requires additional dependencies not currently packaged in obs.
- Rebase existing patches.
- Disable gluegen2-ppc64-aarch64.patch; needs rebase.
* Mon Jul  7 2014 tchvatal@suse.com
- Use junit not junit4
* Thu Jun 19 2014 dvaleev@suse.com
- Fix builds for ppc64, ppc64le and aarch64 architectures
  (gluegen2-ppc64-aarch64.patch)
* Fri Mar 21 2014 badshah400@gmail.com
- Use tagged tarballs released by upstream
  - Requires p7zip
  - Requires manual setup of buildsource directory
- Use full URL for source
- Fix unnecessary executable bits on som files
* Mon Sep 16 2013 dmitry_r@opensuse.org
- Delete ant-* requires for runtime
* Thu Aug  1 2013 ierturk@ieee.org
- Update to version 2.0.2
* Thu Jul 18 2013 dmitry_r@opensuse.org
- Initial package
- Version 2.0-rc12
- Rename library to gluegen2-rt
  * gluegen2-0001-renamed-library.patch
- Disable tests for unused components
  * gluegen2-0003-disable-executable-tmp-tests.patch
- Use system jar files
  * gluegen2-jar-paths.patch
  * gluegen2-0004-add-antlr-jar-to-all-targets.patch
